@@ -221,6 +221,9 @@ pub mod candy_machine {
                             return Err(ErrorCode::NoWhitelistToken.into());
                         }
                         assert_valid_go_live(payer, clock, candy_machine)?;
+                        if ws.mode == WhitelistMintMode::BurnEveryTime {
+                            remaining_accounts_counter += 2;
+                        }
                     }
                 }
                 Err(_) => {
@@ -230,6 +233,9 @@ pub mod candy_machine {
                         // is minting first - a presale whitelist always has an open post sale.
                         return Err(ErrorCode::NoWhitelistToken.into());
                     }
+                    if ws.mode == WhitelistMintMode::BurnEveryTime {
+                        remaining_accounts_counter += 2;
+                    }
                     assert_valid_go_live(payer, clock, candy_machine)?
                 }
             }
@@ -246,6 +252,7 @@ pub mod candy_machine {
             let token_account_info = &ctx.remaining_accounts[remaining_accounts_counter];
             remaining_accounts_counter += 1;
             let transfer_authority_info = &ctx.remaining_accounts[remaining_accounts_counter];
+            remaining_accounts_counter += 1;
             let token_account = assert_is_ata(token_account_info, &payer.key(), &mint)?;
 
             if token_account.amount < price {
@@ -395,10 +402,7 @@ pub mod candy_machine {
             &[&authority_seeds],
         )?;
 
-        if &ctx.remaining_accounts.len() > &(remaining_accounts_counter) {
-            if remaining_accounts_counter != 0 {
-                remaining_accounts_counter += 1;
-            }
+        if &ctx.remaining_accounts.len() == &(remaining_accounts_counter + 6) {
             let collection_pda_account = &ctx.remaining_accounts[remaining_accounts_counter];
             let collection_ref = collection_pda_account.data.borrow();
             let mut collection_pda_data: &[u8] = &collection_ref;
@@ -415,6 +419,8 @@ pub mod candy_machine {
             let collection_master_edition_account =
                 &ctx.remaining_accounts[remaining_accounts_counter];
             remaining_accounts_counter += 1;
+            let collection_update_authority = &ctx.remaining_accounts[remaining_accounts_counter];
+            remaining_accounts_counter += 1;
             let collection_authority_record = &ctx.remaining_accounts[remaining_accounts_counter];
             let cm_ref = candy_machine.key();
             let seeds = [b"collection".as_ref(), cm_ref.as_ref()];
@@ -424,7 +430,7 @@ pub mod candy_machine {
                 ctx.accounts.metadata.to_account_info(),
                 collection_pda_account.to_account_info(),
                 ctx.accounts.payer.to_account_info(),
-                ctx.accounts.update_authority.to_account_info(),
+                collection_update_authority.to_account_info(),
                 collection_mint.to_account_info(),
                 collection_metadata.to_account_info(),
                 collection_master_edition_account.to_account_info(),
@@ -437,7 +443,7 @@ pub mod candy_machine {
                     ctx.accounts.metadata.key(),
                     collection_pda_account.key(),
                     ctx.accounts.payer.key(),
-                    ctx.accounts.update_authority.key(),
+                    collection_update_authority.key(),
                     collection_mint.key(),
                     collection_metadata.key(),
                     collection_master_edition_account.key(),
@@ -989,6 +995,7 @@ pub struct MintNFT<'info> {
     // collection_metadata
     // collection_master_edition_account
     // collection_authority_record
+    // collection_update_authority
 }
 
 /// Update the candy machine state.
